/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo;

/**
 * Describes the attributes used by the Dynamo mail component to retrieve user information.  Also contains
 * the name for the default authenticator and default user permissons.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface UserInfoNamespace
{
  /**
   * The property namespace that contains the user information.
   */
  public static final String NAMESPACE = Namespaces.DYNAMO_USER_INFO_NAMESPACE;

  /**
   * Property name designating the user's full name.
   */
  public static final String ATTR_FULLNAME = "full.name";

  /**
   * Property name designating the user E-mail address.
   */
  public static final String ATTR_EMAIL_ADDRESS = "email.address";

  /**
   * Property name designating the numeric user ID.
   */
  public static final String ATTR_ID = "user.id";

  /**
   * Property name designating the user name.
   */
  public static final String ATTR_USERNAME = "user.name";

  /**
   * Used to designate the default hash password authenticator.
   */
  public static final String AUTH_DEFAULT = "default.hash.password";

  /**
   * The permission that allows user information to be edited.
   */
  public static final String PERM_EDIT_ALL = "edit.all";

} // end interface UserInfoNamespace
