/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.app;

import org.w3c.dom.Element;
import com.silverwrist.util.xml.*;

class HeapContents implements Comparable
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  Element m_elt;    // element we're sorting
  int m_priority;   // its priority

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  HeapContents(Element elt) throws XMLLoadException
  {
    m_elt = elt;
    m_priority = XMLLoader.get().getAttributeInt(elt,"priority",0);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object o)
  {
    if (!(o instanceof HeapContents))
      return false;
    HeapContents other = (HeapContents)o;
    return (m_priority==other.m_priority);

  } // end equals

  public int hashCode()
  {
    return m_priority;

  } // end hashCode

  /*--------------------------------------------------------------------------------
   * Implementations from interface Comparable
   *--------------------------------------------------------------------------------
   */

  public int compareTo(Object o)
  {
    HeapContents other = (HeapContents)o;  // may throw ClassCastException
    return m_priority - other.m_priority;

  } // end compareTo

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  Element getElement()
  {
    return m_elt;

  } // end getElement

} // end class HeapContents
