/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.db;

import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

abstract class ImageStoreOps extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected ImageStoreOps(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class OpsBase
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    super.dispose();

  } // end dispose

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract int imageTypeToIndex(PropertyKey pkey) throws DatabaseException;

  abstract DataItem getImage(int id) throws DatabaseException;

  abstract int saveNewImage(int typecode, int owner_id, int owner_flag, DataItem image)
      throws DatabaseException;

  abstract boolean canReplaceImage(int uid, int image_id) throws DatabaseException;

  abstract void replaceImage(int image_id, DataItem image) throws DatabaseException;

  abstract int findImageID(int typecode, int owner_id, int owner_flag) throws DatabaseException;

  abstract void deleteImage(int image_id) throws DatabaseException;

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static ImageStoreOps get(DBConnectionPool pool) throws ConfigException
  {
    return (ImageStoreOps)get(pool,ImageStoreOps.class.getClassLoader(),
			      ImageStoreOps.class.getName() + "_","ImageStoreOps");

  } // end get

} // end class ImageStoreOps
