/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.except;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.ResourceBundle;
import com.silverwrist.dynamo.iface.DynamicClass;

public class CodeNotFoundException extends DynamicObjectException
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String BUNDLE = "com.silverwrist.dynamo.except.DynamoExceptionMessages";

  public static final int CALL = 0;
  public static final int GET = 1;
  public static final int SET = 2;
  public static final int PROPERTY = 3;

  private static final String[] s_messages =
      { "codeNotFound.call", "codeNotFound.get", "codeNotFound.set", "codeNotFound.prop" };
  
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_message_id;
  private Object[] m_args;
  private String m_message = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public CodeNotFoundException(DynamicClass klass, int selector, String name)
  {
    super("");
    m_message_id = s_messages[selector];
    m_args = new Object[2];
    m_args[0] = klass.getName();
    m_args[1] = name;

  } // end constructor

  public CodeNotFoundException(DynamicClass klass, int selector, String name, Throwable inner)
  {
    super("",inner);
    m_message_id = s_messages[selector];
    m_args = new Object[2];
    m_args[0] = klass.getName();
    m_args[1] = name;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Throwable
   *--------------------------------------------------------------------------------
   */

  public String getMessage()
  {
    if (m_message==null)
      m_message = getLocalizedMessage(Locale.US);
    return m_message;

  } // end getMessage

  /**
   * Creates a localized description of this exception. Subclasses may override this method in
   * order to produce a locale-specific message. For subclasses that do not override this method,
   * the default implementation returns the same result as <CODE>getMessage()</CODE>.
   *
   * @return The localized description of this exception.
   */
  public String getLocalizedMessage()
  {
    return this.getLocalizedMessage(Locale.getDefault());

  } // end getLocalizedMessage

  /*--------------------------------------------------------------------------------
   * Overrides from class DynamoRuntimeException
   *--------------------------------------------------------------------------------
   */

  /**
   * Creates a localized description of this exception. Subclasses may override this method in
   * order to produce a locale-specific message. For subclasses that do not override this method,
   * the default implementation returns the same result as <CODE>getLocalizedMessage()</CODE>.
   *
   * @param locale The locale to render the message in.
   * @return The localized description of this exception.
   */
  public String getLocalizedMessage(Locale locale)
  {
    ResourceBundle b = ResourceBundle.getBundle(BUNDLE,locale,getClass().getClassLoader());
    return MessageFormat.format(b.getString(m_message_id),m_args);

  } // end getLocalizedMessage

} // end class CodeNotFoundException
