/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.except;

/**
 * An exception thrown indicating a problem with the database.  This commonly wraps a
 * <CODE>java.sql.SQLException</CODE>, but may also indicate a problem with a connection pool or such.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public class DatabaseException extends ExternalException
{
  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>DatabaseException</CODE> instance.
   *
   * @param caller The classname of the class that's creating the exception.  Its class loader
   *               and package name will be used, together with <CODE>bundle</CODE>, to find the
   *               resource bundle.
   * @param bundle The name of the resource bundle to be loaded.
   * @param message_id The identifier of the message to be loaded from the bundle.
   */
  public DatabaseException(Class caller, String bundle, String message_id)
  {
    super(caller,bundle,message_id);

  } // end constructor

  /**
   * Constructs a new <CODE>DatabaseException</CODE> instance.
   *
   * @param caller The classname of the class that's creating the exception.  Its class loader
   *               and package name will be used, together with <CODE>bundle</CODE>, to find the
   *               resource bundle.
   * @param bundle The name of the resource bundle to be loaded.
   * @param message_id The identifier of the message to be loaded from the bundle.
   * @param inner The exception to be nested inside this one.
   */
  public DatabaseException(Class caller, String bundle, String message_id, Throwable inner)
  {
    super(caller,bundle,message_id,inner);

  } // end constructor

} // end class DatabaseException
