/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * The interface implemented by an <EM>application object</EM>.  This is the object referenced by the
 * <code>classname=</code> attribute to the <code>&lt;application/&gt;</code> tag in the
 * Dynamo configuration file.  The application container uses this to communicate with the
 * application object.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface Application extends NamedObject, ServiceProvider
{
  /**
   * Gets the identity of this application.  This identity is used along with the Dynamo version number in
   * such contexts as the <code>Server:</code> header of the HTTP response and the <code>X-Mailer:</code>
   * header of composed mail messages.
   *
   * @return The identity of the application, in the form "name/version".
   */
  public String getIdentity();

  /**
   * Gets an object to be rendered in place of the content returned by the control operation when that
   * content is a <code>null</code> reference.
   *
   * @param r The <code>Request</code> that is currently being processed.
   * @return A renderable object to be output.
   */
  public Object getNullContentError(Request r);

} // end interface Application

