/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.io.IOException;
import com.silverwrist.dynamo.except.RenderingException;

/**
 * An interface implemented by <EM>rendering objects</EM> which renders the specified object as a binary object
 * (such as an image, file attachment, or similar).  The rendering object uses the data in the supplied object, as
 * well as the methods supplied in the {@link com.silverwrist.dynamo.iface.BinaryRenderControl BinaryRenderControl}
 * interface, to generate an output rendering.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface BinaryRenderer extends Renderer
{
  /**
   * Renders the specified object to the output in binary mode.
   *
   * @param obj The object to be rendered.
   * @param control A rendering control object that provides the means to render this object to the output, as
   *                well as providing "output services" (through the
   *                {@link com.silverwrist.dynamo.iface.ServiceProvider ServiceProvider} interface) for the
   *                rendering process to use.
   * @exception java.io.IOException If an I/O error occurs while writing the output.
   * @exception com.silverwrist.dynamo.except.RenderingException If the rendering process fails.
   */
  public void render(Object obj, BinaryRenderControl control) throws IOException, RenderingException;
  
} // end interface BinaryRenderer
