/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.util.Collection;

/**
 * A request service interface which allows access to parameters passed to the request through the
 * {@link javax.servlet.ServletRequest ServletRequest} object, and not via Dynamo.  This will often be needed, for
 * instance, to interface with servlet-based APIs outside the scope of Dynamo.
 * <P><B>N.B.:</B> Dynamo itself requires several request-level parameters to manage its current state
 * (such as the {@link com.silverwrist.dynamo.iface.Request Request} object).  This service will not permit access
 * to those reserved request-level parameters.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface ChainParameterInput
{
  /**
   * Returns a {@link java.util.Collection Collection} containing all names of external request parameters.
   * Request parameters used internally by Dynamo itself will <EM>not</EM> be included in this list.
   *
   * @return The collection of parameter names.
   */
  public Collection getChainParameterNames();

  /**
   * Returns the value of an external request parameter.  Attempts to get the value of a request parameter used
   * internally by Dynamo itself will return <CODE>null</CODE>.
   *
   * @param name The name of the parameter to retrieve.
   * @return The parameter's value, or <CODE>null</CODE> if the parameter did not exist.
   */
  public Object getChainParameter(String name);

} // end interface ChainParameterInput
