/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.http.HttpServletResponse;
import com.silverwrist.dynamo.except.RenderingException;

/**
 * The parent interface of <EM>rendering control objects</EM>, which provide the means by which rendering objects can
 * output their renderings to the user's browser.  All rendering control objects incorporate a
 * {@link com.silverwrist.dynamo.iface.ServiceProvider ServiceProvider} interface, which supplies "output services"
 * for the use of the rendering object.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface RenderControl extends ServiceProvider
{
  /**
   * Sets the content type (MIME type) of the output.
   *
   * @param type The content type to be set.
   * @exception com.silverwrist.dynamo.except.RenderingException If there was a problem setting the content type.
   */
  public void setContentType(String type) throws RenderingException;

  /**
   * Sets the content length (in bytes) for the output.
   *
   * @param length The content length to be set.
   * @exception com.silverwrist.dynamo.except.RenderingException If there was a problem setting the content length.
   */
  public void setContentLength(int length) throws RenderingException;

} // end interface RenderControl
