/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002-03 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.iface;

/**
 * An initialization service which allows objects to be registered with a newly-created scripting engine.  Objects
 * registered via this service may be retrieved via the <CODE>bsf.lookupBean()</CODE> script function (or equivalent
 * in the scripting language).<P>
 * This interface is passed as part of the
 * {@link com.silverwrist.dynamo.event.ScriptEngineStartEvent ScriptEngineStartEvent} object, where it may be retrieved
 * by an event listener.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 */
public interface ScriptEngineRegisterObject
{
  /**
   * Registers a new object with the scripting engine.
   *
   * @param name Name that this object is to be accessible under.
   * @param obj The object to be registered.
   */
  public void registerObject(String name, Object obj);

} // end interface ScriptEngineRegisterObject
