/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.security;

import java.security.acl.LastOwnerException;
import java.security.acl.NotOwnerException;
import java.util.Set;
import com.silverwrist.dynamo.db.OpsBase;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

abstract class AclOperations extends OpsBase
{
  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  protected AclOperations(DBConnectionPool pool)
  {
    super(pool);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class OpsBase
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    super.dispose();

  } // end dispose

  /*--------------------------------------------------------------------------------
   * Abstract operations
   *--------------------------------------------------------------------------------
   */

  abstract boolean testOwner(int aclid, PrincipalID owner) throws DatabaseException;

  abstract boolean addOwner(int aclid, PrincipalID caller, PrincipalID owner)
      throws DatabaseException, NotOwnerException;

  abstract boolean deleteOwner(int aclid, PrincipalID caller, PrincipalID owner)
      throws DatabaseException, NotOwnerException, LastOwnerException;

  abstract void setAclName(int aclid, PrincipalID caller, String name)
      throws DatabaseException, NotOwnerException;

  abstract int getAceCount(int aclid) throws DatabaseException;

  abstract int getAceID(int aclid, PrincipalID caller, int index) throws DatabaseException, NotOwnerException;

  abstract boolean insertAce(int aclid, PrincipalID caller, int aceid, int at_index)
      throws DatabaseException, NotOwnerException;

  abstract boolean removeAce(int aclid, PrincipalID caller, int aceid)
      throws DatabaseException, NotOwnerException;

  abstract Set getGroupPermissionSetForUser(int aclid, int uid, boolean negative) throws DatabaseException;

  abstract Set getGroupPermissionSetForGroup(int aclid, int gid, boolean negative) throws DatabaseException;

  abstract Set getUserPermissionSet(int aclid, int uid, boolean negative) throws DatabaseException;

  abstract boolean testUserPermission(int aclid, int uid, PropertyKey perm) throws DatabaseException;

  abstract boolean testGroupPermission(int aclid, int gid, PropertyKey perm) throws DatabaseException;

  abstract int[] getAceIDs(int aclid) throws DatabaseException;

} // end class AclOperations
