/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.security;

import java.security.Principal;
import com.silverwrist.dynamo.iface.*;

final class PrincipalID
{ 
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private int m_id;
  private boolean m_group;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  PrincipalID(int id, boolean group)
  {
    m_id = id;
    m_group = group;

  } // end constructor

  PrincipalID(Principal pr)
  {
    if (pr instanceof DynamoUser)
    { // get the user ID
      m_id = ((DynamoUser)pr).getUID();
      m_group = false;

    } // end if
    else if (pr instanceof DynamoGroup)
    { // get the group ID
      m_id = ((DynamoGroup)pr).getGID();
      m_group = true;
	
    } // end else if
    else
      throw new IllegalArgumentException("argument must be DynamoUser or DynamoGroup");

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object o)
  {
    if ((o==null) || !(o instanceof PrincipalID))
      return false;
    PrincipalID other = (PrincipalID)o;
    return ((m_id==other.m_id) && (m_group==other.m_group));

  } // end equals

  public int hashCode()
  {
    return ((m_id << 1) | (m_group ? 1 : 0));

  } // end hashCode

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  int getID()
  {
    return m_id;

  } // end getID

  boolean isGroup()
  {
    return m_group;

  } // end isGroup

} // end class PrincipalID
