/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import java.util.*;
import com.silverwrist.dynamo.iface.*;

class NullBrowserData implements BrowserData
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String UNKNOWN = "unknown";
  private static final String ZERO = "0";

  private static NullBrowserData _self = null;

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private HashMap m_values = new HashMap();

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  private NullBrowserData()
  {
    m_values.put(KEY_BROWSER_NAME,UNKNOWN);
    m_values.put(KEY_VERSION,ZERO);
    m_values.put(KEY_MAJOR_VERSION,ZERO);
    m_values.put(KEY_MINOR_VERSION,ZERO);
    m_values.put(KEY_PLATFORM,UNKNOWN);
    m_values.put(KEY_CLR_VERSION,ZERO);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface BrowserData
   *--------------------------------------------------------------------------------
   */

  public String getUserAgent()
  {
    return "";

  } // end getUserAgent

  public String getBrowserAttribute(String key)
  {
    return (String)(m_values.get(key));

  } // end getBrowserAttribute

  public Set getBrowserFlags()
  {
    return Collections.EMPTY_SET;

  } // end getBrowserFlags

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static BrowserData get()
  {
    if (_self==null)
      _self = new NullBrowserData();
    return _self;

  } // end get

} // end class NullBrowserData
