/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.servlet;

import com.silverwrist.dynamo.HttpStatusCode;
import com.silverwrist.dynamo.Namespaces;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

public class RemapperServlet extends ServletBase
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private GetRemapperData m_remapper;

  /*--------------------------------------------------------------------------------
   * Abstract implementations from class ServletBase
   *--------------------------------------------------------------------------------
   */

  protected Object process(Request r, Application app) throws Exception
  {
    Remapper remap = m_remapper.getRemapper(r.getRequestPath());
    if (remap==null)
      return new HttpErrorMessage(HttpStatusCode.E_NOTFOUND);
    remap.setParameters(r);
    return remap;

  } // end process

  /*--------------------------------------------------------------------------------
   * Overrides from class ServletBase
   *--------------------------------------------------------------------------------
   */

  protected void initServlet(ServiceProvider services) throws DynamoException
  {
    // Get the name of the remapper data object
    ObjectProvider oprov = (ObjectProvider)(services.queryService(ObjectProvider.class));
    String subsys_name = (String)(oprov.getObject(Namespaces.SERVLET_INIT_NAMESPACE,"data.object"));

    // Get the remapper data object.
    m_remapper = (GetRemapperData)(GetObjectUtils.getDynamoComponent(services,GetRemapperData.class,
								     subsys_name));

  } // end initServlet

} // end class RemapperServlet
