/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.util;

public final class DynamoIDKey implements Cloneable, Comparable
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_val;
  private int m_hc;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public DynamoIDKey(String val)
  {
    if (val==null)
      throw new NullPointerException();
    m_val = val;
    m_hc = val.toLowerCase().hashCode();

  } // end constructor

  private DynamoIDKey(String val, int hc)
  {
    m_val = val;
    m_hc = hc;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public Object clone()
  {
    return new DynamoIDKey(m_val,m_hc);

  } // end clone

  public boolean equals(Object o)
  {
    if ((o==null) || !(o instanceof DynamoIDKey))
      return false;
    DynamoIDKey other = (DynamoIDKey)o;
    return m_val.equalsIgnoreCase(other.m_val);

  } // end equals

  public int hashCode()
  {
    return m_hc;

  } // end hashCode

  public String toString()
  {
    return m_val;

  } // end toString

  /*--------------------------------------------------------------------------------
   * Implementations from interface Comparable
   *--------------------------------------------------------------------------------
   */

  public int compareTo(Object o)
  {
    DynamoIDKey other = (DynamoIDKey)o;  // may throw ClassCastException
    return m_val.compareToIgnoreCase(other.m_val);

  } // end compareTo

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public boolean isValid()
  {
    return IDUtils.isValidDynamoID(m_val);

  } // end isValid

  public boolean isValid(int maxlen)
  {
    return IDUtils.isValidDynamoID(m_val,maxlen);

  } // end isValid

  public int length()
  {
    return m_val.length();

  } // end length

} // end class DynamoIDKey
