/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2002 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.xmlrpc;

import java.util.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

class MultiCallRequest extends FilterRequest
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_method;
  private Map m_params;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  MultiCallRequest(Request inner, String method, List params)
  {
    super(inner);
    m_method = method;
    HashMap tmp = new HashMap();
    Iterator it = params.iterator();
    int ndx = 0;
    while (it.hasNext())
      tmp.put(String.valueOf(ndx++),it.next());
    if (tmp.isEmpty())
      m_params = Collections.EMPTY_MAP;
    else
      m_params = Collections.unmodifiableMap(tmp);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class FilterRequest
   *--------------------------------------------------------------------------------
   */

  public String getQueryString()
  {
    return m_method;

  } // end getQueryString

  public Map getParameters()
  {
    return m_params;

  } // end getParameters

} // end class MultiCallRequest
