/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.dynamo.testmod;

import java.security.Principal;
import org.apache.log4j.Logger;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;

public class Main implements ModuleFunctions
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Logger logger = Logger.getLogger(Main.class);

  private static final QualifiedNameKey ID =
      new QualifiedNameKey("http://www.silverwrist.com/NS/dynamo/2003/05/18/testapp","testmodule");

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private ModuleSite m_site;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public Main()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface ModuleFunctions
   *--------------------------------------------------------------------------------
   */

  public QualifiedNameKey getModuleID()
  {
    return ID;

  } // end getModuleID

  public void initialize(ModuleSite site, ServiceProvider services) throws ModuleException
  {
    m_site = site;
    logger.info("TestMod Main initializing");

  } // end initialize

  public void shutdown()
  {
    m_site = null;
    logger.info("TestMod Main shutting down");

  } // end shutdown

  public boolean inUse()
  {
    return false;  // dummy out

  } // end inUse

  public boolean canInstall(ServiceProvider services, Principal installer)
  {
    return true;

  } // end canInstall

  public void install(ModuleSite site, ServiceProvider services, Principal installer) throws ModuleException
  {
    // module does not need installation
  } // end install

  public void uninstall(ModuleSite site, ServiceProvider services, Principal uninstaller) throws ModuleException
  {
    // module does not need uninstallation
  } // end uninstall

  public DynamicObject getProvidedObject(String namespace, String name) throws ModuleException
  {
    if (namespace.equals(ID.getNamespace()) && name.equals("test1"))
      return new TestMod1DObject(m_site);
    return null;

  } // end getProvidedObject

} // end class Main
